diff --git a/books/bookvol10.2.pamphlet b/books/bookvol10.2.pamphlet
index 4f3888b..c341865 100644
--- a/books/bookvol10.2.pamphlet
+++ b/books/bookvol10.2.pamphlet
@@ -10941,6 +10941,224 @@ digraph pic {
 }
 @
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+\pagehead{PlacesCategory}{PLACESC}
+\pagepic{ps/v102placescategory.eps}{PLACESC}{0.75}
+
+<<PlacesCategory.input>>=
+)set break resume
+)sys rm -f PlacesCategory.output
+)spool PlacesCategory.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 1
+)show PlacesCategory
+--R PlacesCategory(K: Field,PCS: LocalPowerSeriesCategory t#1)  is a category constructor
+--R Abbreviation for PlacesCategory is PLACESC 
+--R This constructor is exposed in this frame.
+--R Issue )edit bookvol10.2.pamphlet to see algebra source code for PLACESC 
+--R
+--R------------------------------- Operations --------------------------------
+--R ?*? : (Integer,%) -> Divisor %        ?+? : (%,%) -> Divisor %
+--R -? : % -> Divisor %                   ?-? : (%,%) -> Divisor %
+--R ?=? : (%,%) -> Boolean                coerce : % -> OutputForm
+--R create : Symbol -> %                  create : List K -> %
+--R degree : % -> PositiveInteger         ?.? : (%,Integer) -> K
+--R foundPlaces : () -> List %            hash : % -> SingleInteger
+--R itsALeaf! : % -> Void                 latex : % -> String
+--R leaf? : % -> Boolean                  localParam : % -> List PCS
+--R reduce : List % -> Divisor %          setParam! : (%,List PCS) -> Void
+--R ?~=? : (%,%) -> Boolean              
+--R ?+? : (%,Divisor %) -> Divisor %
+--R ?+? : (Divisor %,%) -> Divisor %
+--R ?-? : (%,Divisor %) -> Divisor %
+--R ?-? : (Divisor %,%) -> Divisor %
+--R setDegree! : (%,PositiveInteger) -> Void
+--R setFoundPlacesToEmpty : () -> List %
+--R
+--E 1
+
+)spool
+)lisp (bye)
+@
+<<PlacesCategory.help>>=
+====================================================================
+PlacesCategory examples
+====================================================================
+
+See Also:
+o )show PlacesCategory
+
+@
+
+{\bf See:}
+
+\pagefrom{SetCategoryWithDegree}{SETCATD}
+
+{\bf Exports:}\\
+
+\begin{tabular}{llll}
+\cross{PLACESC}{-?} &
+\cross{PLACESC}{?*?} &
+\cross{PLACESC}{?+?} &
+\cross{PLACESC}{?-?} \\
+\cross{PLACESC}{?.?} &
+\cross{PLACESC}{?=?} &
+\cross{PLACESC}{?\~{}=?} &
+\cross{PLACESC}{coerce} \\
+\cross{PLACESC}{create} &
+\cross{PLACESC}{degree} &
+\cross{PLACESC}{foundPlaces} &
+\cross{PLACESC}{hash} \\
+\cross{PLACESC}{itsALeaf!} &
+\cross{PLACESC}{latex} &
+\cross{PLACESC}{leaf?} &
+\cross{PLACESC}{localParam} \\
+\cross{PLACESC}{reduce} &
+\cross{PLACESC}{setDegree!} &
+\cross{PLACESC}{setFoundPlacesToEmpty} &
+\cross{PLACESC}{setParam!}
+\end{tabular}
+
+These are directly exported but not implemented:
+\begin{verbatim}
+ -? : % -> Divisor %                  
+ ?*? : (Integer,%) -> Divisor %       
+ ?+? : (%,%) -> Divisor %
+ ?+? : (%,Divisor %) -> Divisor %
+ ?+? : (Divisor %,%) -> Divisor %
+ ?-? : (%,%) -> Divisor %
+ ?-? : (%,Divisor %) -> Divisor %
+ ?-? : (Divisor %,%) -> Divisor %
+ ?.? : (%,Integer) -> K
+ create : List K -> %
+ create : Symbol -> %                 
+ foundPlaces : () -> List %           
+ itsALeaf! : % -> Void                
+ leaf? : % -> Boolean                 
+ localParam : % -> List PCS
+ reduce : List % -> Divisor %         
+ setDegree! : (%,PositiveInteger) -> Void
+ setFoundPlacesToEmpty : () -> List %
+ setParam! : (%,List PCS) -> Void
+\end{verbatim}
+
+These exports come from \refto{SetCategoryWithDegree}
+\begin{verbatim}
+ ?=? : (%,%) -> Boolean               
+ ?~=? : (%,%) -> Boolean
+ coerce : % -> OutputForm
+ degree : % -> PositiveInteger        
+ hash : % -> SingleInteger
+ latex : % -> String                  
+\end{verbatim}
+
+<<category PLACESC PlacesCategory>>=
+)abbrev category PLACESC PlacesCategory
+++ Author: Gaetan Hache
+++ Date Created: 17 nov 1992
+++ Date Last Updated: May 2010 by Tim Daly
+++ Description:
+++ This is part of the PAFF package, related to projective space.
+PlacesCategory(K:Field,PCS:LocalPowerSeriesCategory(K)):Category
+  == SetCategoryWithDegree with
+
+    "+": (%,%)       -> Divisor(%)
+
+    "+": (Divisor(%) , % ) -> Divisor(%)
+
+    "+": (%, Divisor(%)) -> Divisor(%)
+
+    "-": (%,%)       -> Divisor(%)
+
+    "-": (Divisor(%) , % ) -> Divisor(%)
+
+    "-": (%, Divisor(%)) -> Divisor(%)
+
+    "-": % -> Divisor(%)
+
+    "*": (Integer,%) -> Divisor(%)
+
+    reduce: List %   -> Divisor(%)
+
+    create: List K -> %
+
+    create: Symbol -> %
+
+    localParam: % -> List PCS
+      ++ localParam(pl) returns the local parametrization associated 
+      ++ to the place pl.
+
+    setParam_!: (%,List PCS)  -> Void
+      ++ setParam!(pl,ls) set the local parametrization of pl to ls.
+
+    setDegree_!: (%,PositiveInteger)  -> Void
+      ++ setDegree!(pl,ls) set the degree.
+
+    leaf?: % -> Boolean
+      ++ leaf?(pl) test if the place pl correspond to a leaf of a 
+      ++ desingularisation tree.
+
+    itsALeaf_!: % -> Void
+
+    foundPlaces: () -> List %
+      ++ foundPlaces() returns the list of all "created" places up to now.
+
+    setFoundPlacesToEmpty: () -> List %
+      ++ setFoundPlacesToEmpty() does what it says. 
+      ++ (this should not be used)!!!
+
+    elt: (%,Integer) -> K
+      ++ elt returns the value of a specified coordinates if the places 
+      ++ correspnd to a simple point
+
+@
+<<PLACESC.dotabb>>=
+"PLACESC" [color=lightblue,href="bookvol10.2.pdf#nameddest=PLACESC"];
+"PLACESC" -> "SETCATD"
+
+@
+<<PLACESC.dotfull>>=
+"PlacesCategory()" [color=lightblue,href="bookvol10.2.pdf#nameddest=PLACESC"];
+"PlacesCategory()" -> "SetCategoryWithDegree()"
+
+@
+<<PLACESC.dotpic>>=
+digraph pic {
+ fontsize=10;
+ bgcolor="#FFFF66";
+ node [shape=box, color=white, style=filled];
+
+"PlacesCategory()" [color=lightblue];
+"PlacesCategory()" -> "SetCategoryWithDegree()"
+
+"SetCategoryWithDegree()" [color=lightblue];
+"SetCategoryWithDegree()" -> "BasicType()"
+"SetCategoryWithDegree()" -> "CoercibleTo(OutputForm)"
+"SetCategoryWithDegree()" -> "SetCategory()"
+
+"SetCategory()" [color=lightblue];
+"SetCategory()" -> "BasicType()"
+"SetCategory()" -> "CoercibleTo(OutputForm)"
+
+"BasicType()" [color=lightblue];
+"BasicType()" -> "Category"
+
+"CoercibleTo(OutputForm)" [color=seagreen];
+"CoercibleTo(OutputForm)" -> "CoercibleTo(a:Type)"
+
+"CoercibleTo(a:Type)" [color=lightblue];
+"CoercibleTo(a:Type)" -> "Category"
+
+"Package" [color="#00EE00"];
+
+"Category" [color=lightblue];
+
+}
+
+@
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 \pagehead{ProjectiveSpaceCategory}{PRSPCAT}
 \pagepic{ps/v102projectivespacecategory.ps}{PRSPCAT}{0.75}
 
@@ -76908,6 +77126,7 @@ Note that this code is not included in the generated catdef.spad file.
 <<category PATAB Patternable>>
 <<category PATMAB PatternMatchable>>
 <<category PERMCAT PermutationCategory>>
+<<category PLACESC PlacesCategory>>
 <<category PPCURVE PlottablePlaneCurveCategory>>
 <<category PSCURVE PlottableSpaceCurveCategory>>
 <<category PTCAT PointCategory>>
@@ -77140,6 +77359,7 @@ digraph dotabb {
 <<PERMCAT.dotabb>>
 <<PFECAT.dotabb>>
 <<PID.dotabb>>
+<<PLACESC.dotabb>>
 <<POLYCAT.dotabb>>
 <<PPCURVE.dotabb>>
 <<PRIMCAT.dotabb>>
@@ -77362,6 +77582,7 @@ digraph dotfull {
 <<PERMCAT.dotfull>>
 <<PFECAT.dotfull>>
 <<PID.dotfull>>
+<<PLACESC.dotfull>>
 <<POLYCAT.dotfull>>
 <<PPCURVE.dotfull>>
 <<PRIMCAT.dotfull>>
diff --git a/books/ps/v102placescategory.eps b/books/ps/v102placescategory.eps
new file mode 100644
index 0000000..ae4b09a
--- /dev/null
+++ b/books/ps/v102placescategory.eps
@@ -0,0 +1,538 @@
+%!PS-Adobe-3.0 EPSF-3.0
+%%Creator: Graphviz version 2.20.2 (Mon Mar 30 10:09:11 UTC 2009)
+%%For: (root) root
+%%Title: pic
+%%Pages: 1
+%%BoundingBox: 36 36 342 440
+%%EndComments
+save
+%%BeginProlog
+/DotDict 200 dict def
+DotDict begin
+
+/setupLatin1 {
+mark
+/EncodingVector 256 array def
+ EncodingVector 0
+
+ISOLatin1Encoding 0 255 getinterval putinterval
+EncodingVector 45 /hyphen put
+
+% Set up ISO Latin 1 character encoding
+/starnetISO {
+        dup dup findfont dup length dict begin
+        { 1 index /FID ne { def }{ pop pop } ifelse
+        } forall
+        /Encoding EncodingVector def
+        currentdict end definefont
+} def
+/Times-Roman starnetISO def
+/Times-Italic starnetISO def
+/Times-Bold starnetISO def
+/Times-BoldItalic starnetISO def
+/Helvetica starnetISO def
+/Helvetica-Oblique starnetISO def
+/Helvetica-Bold starnetISO def
+/Helvetica-BoldOblique starnetISO def
+/Courier starnetISO def
+/Courier-Oblique starnetISO def
+/Courier-Bold starnetISO def
+/Courier-BoldOblique starnetISO def
+cleartomark
+} bind def
+
+%%BeginResource: procset graphviz 0 0
+/coord-font-family /Times-Roman def
+/default-font-family /Times-Roman def
+/coordfont coord-font-family findfont 8 scalefont def
+
+/InvScaleFactor 1.0 def
+/set_scale {
+       dup 1 exch div /InvScaleFactor exch def
+       scale
+} bind def
+
+% styles
+/solid { [] 0 setdash } bind def
+/dashed { [9 InvScaleFactor mul dup ] 0 setdash } bind def
+/dotted { [1 InvScaleFactor mul 6 InvScaleFactor mul] 0 setdash } bind def
+/invis {/fill {newpath} def /stroke {newpath} def /show {pop newpath} def} bind def
+/bold { 2 setlinewidth } bind def
+/filled { } bind def
+/unfilled { } bind def
+/rounded { } bind def
+/diagonals { } bind def
+
+% hooks for setting color 
+/nodecolor { sethsbcolor } bind def
+/edgecolor { sethsbcolor } bind def
+/graphcolor { sethsbcolor } bind def
+/nopcolor {pop pop pop} bind def
+
+/beginpage {	% i j npages
+	/npages exch def
+	/j exch def
+	/i exch def
+	/str 10 string def
+	npages 1 gt {
+		gsave
+			coordfont setfont
+			0 0 moveto
+			(\() show i str cvs show (,) show j str cvs show (\)) show
+		grestore
+	} if
+} bind def
+
+/set_font {
+	findfont exch
+	scalefont setfont
+} def
+
+% draw text fitted to its expected width
+/alignedtext {			% width text
+	/text exch def
+	/width exch def
+	gsave
+		width 0 gt {
+			[] 0 setdash
+			text stringwidth pop width exch sub text length div 0 text ashow
+		} if
+	grestore
+} def
+
+/boxprim {				% xcorner ycorner xsize ysize
+		4 2 roll
+		moveto
+		2 copy
+		exch 0 rlineto
+		0 exch rlineto
+		pop neg 0 rlineto
+		closepath
+} bind def
+
+/ellipse_path {
+	/ry exch def
+	/rx exch def
+	/y exch def
+	/x exch def
+	matrix currentmatrix
+	newpath
+	x y translate
+	rx ry scale
+	0 0 1 0 360 arc
+	setmatrix
+} bind def
+
+/endpage { showpage } bind def
+/showpage { } def
+
+/layercolorseq
+	[	% layer color sequence - darkest to lightest
+		[0 0 0]
+		[.2 .8 .8]
+		[.4 .8 .8]
+		[.6 .8 .8]
+		[.8 .8 .8]
+	]
+def
+
+/layerlen layercolorseq length def
+
+/setlayer {/maxlayer exch def /curlayer exch def
+	layercolorseq curlayer 1 sub layerlen mod get
+	aload pop sethsbcolor
+	/nodecolor {nopcolor} def
+	/edgecolor {nopcolor} def
+	/graphcolor {nopcolor} def
+} bind def
+
+/onlayer { curlayer ne {invis} if } def
+
+/onlayers {
+	/myupper exch def
+	/mylower exch def
+	curlayer mylower lt
+	curlayer myupper gt
+	or
+	{invis} if
+} def
+
+/curlayer 0 def
+
+%%EndResource
+%%EndProlog
+%%BeginSetup
+14 default-font-family set_font
+1 setmiterlimit
+% /arrowlength 10 def
+% /arrowwidth 5 def
+
+% make sure pdfmark is harmless for PS-interpreters other than Distiller
+/pdfmark where {pop} {userdict /pdfmark /cleartomark load put} ifelse
+% make '<<' and '>>' safe on PS Level 1 devices
+/languagelevel where {pop languagelevel}{1} ifelse
+2 lt {
+    userdict (<<) cvn ([) cvn load put
+    userdict (>>) cvn ([) cvn load put
+} if
+
+%%EndSetup
+setupLatin1
+%%Page: 1 1
+%%PageBoundingBox: 36 36 342 440
+%%PageOrientation: Portrait
+0 0 1 beginpage
+gsave
+36 36 306 404 boxprim clip newpath
+1 1 set_scale 0 rotate 40 40 translate
+% PlacesCategory()
+gsave
+0.537 0.247 0.902 nodecolor
+newpath 191 396 moveto
+59 396 lineto
+59 360 lineto
+191 360 lineto
+closepath fill
+1 setlinewidth
+filled
+0.537 0.247 0.902 nodecolor
+newpath 191 396 moveto
+59 396 lineto
+59 360 lineto
+191 360 lineto
+closepath stroke
+0.000 0.000 0.000 nodecolor
+14 /Times-Roman set_font
+67 373.9 moveto 116 (PlacesCategory\(\)) alignedtext
+grestore
+% SetCategoryWithDegree()
+gsave
+0.537 0.247 0.902 nodecolor
+newpath 223 324 moveto
+27 324 lineto
+27 288 lineto
+223 288 lineto
+closepath fill
+1 setlinewidth
+filled
+0.537 0.247 0.902 nodecolor
+newpath 223 324 moveto
+27 324 lineto
+27 288 lineto
+223 288 lineto
+closepath stroke
+0.000 0.000 0.000 nodecolor
+14 /Times-Roman set_font
+34.5 301.9 moveto 181 (SetCategoryWithDegree\(\)) alignedtext
+grestore
+% PlacesCategory()->SetCategoryWithDegree()
+gsave
+1 setlinewidth
+0.000 0.000 0.000 edgecolor
+newpath 125 360 moveto
+125 352 125 343 125 334 curveto
+stroke
+0.000 0.000 0.000 edgecolor
+newpath 128.5 334 moveto
+125 324 lineto
+121.5 334 lineto
+closepath fill
+1 setlinewidth
+solid
+0.000 0.000 0.000 edgecolor
+newpath 128.5 334 moveto
+125 324 lineto
+121.5 334 lineto
+closepath stroke
+grestore
+% BasicType()
+gsave
+0.537 0.247 0.902 nodecolor
+newpath 92 180 moveto
+0 180 lineto
+0 144 lineto
+92 144 lineto
+closepath fill
+1 setlinewidth
+filled
+0.537 0.247 0.902 nodecolor
+newpath 92 180 moveto
+0 180 lineto
+0 144 lineto
+92 144 lineto
+closepath stroke
+0.000 0.000 0.000 nodecolor
+14 /Times-Roman set_font
+7.5 157.9 moveto 77 (BasicType\(\)) alignedtext
+grestore
+% SetCategoryWithDegree()->BasicType()
+gsave
+1 setlinewidth
+0.000 0.000 0.000 edgecolor
+newpath 95 288 moveto
+82 279 68 266 60 252 curveto
+50 233 47 209 46 190 curveto
+stroke
+0.000 0.000 0.000 edgecolor
+newpath 49.48 189.6 moveto
+45 180 lineto
+42.51 190.3 lineto
+closepath fill
+1 setlinewidth
+solid
+0.000 0.000 0.000 edgecolor
+newpath 49.48 189.6 moveto
+45 180 lineto
+42.51 190.3 lineto
+closepath stroke
+grestore
+% CoercibleTo(OutputForm)
+gsave
+0.404 0.667 0.545 nodecolor
+newpath 298 180 moveto
+110 180 lineto
+110 144 lineto
+298 144 lineto
+closepath fill
+1 setlinewidth
+filled
+0.404 0.667 0.545 nodecolor
+newpath 298 180 moveto
+110 180 lineto
+110 144 lineto
+298 144 lineto
+closepath stroke
+0.000 0.000 0.000 nodecolor
+14 /Times-Roman set_font
+117.5 157.9 moveto 173 (CoercibleTo\(OutputForm\)) alignedtext
+grestore
+% SetCategoryWithDegree()->CoercibleTo(OutputForm)
+gsave
+1 setlinewidth
+0.000 0.000 0.000 edgecolor
+newpath 155 288 moveto
+167 279 181 266 190 252 curveto
+200 233 203 209 204 190 curveto
+stroke
+0.000 0.000 0.000 edgecolor
+newpath 207.49 190.3 moveto
+205 180 lineto
+200.52 189.6 lineto
+closepath fill
+1 setlinewidth
+solid
+0.000 0.000 0.000 edgecolor
+newpath 207.49 190.3 moveto
+205 180 lineto
+200.52 189.6 lineto
+closepath stroke
+grestore
+% SetCategory()
+gsave
+0.537 0.247 0.902 nodecolor
+newpath 181 252 moveto
+69 252 lineto
+69 216 lineto
+181 216 lineto
+closepath fill
+1 setlinewidth
+filled
+0.537 0.247 0.902 nodecolor
+newpath 181 252 moveto
+69 252 lineto
+69 216 lineto
+181 216 lineto
+closepath stroke
+0.000 0.000 0.000 nodecolor
+14 /Times-Roman set_font
+76.5 229.9 moveto 97 (SetCategory\(\)) alignedtext
+grestore
+% SetCategoryWithDegree()->SetCategory()
+gsave
+1 setlinewidth
+0.000 0.000 0.000 edgecolor
+newpath 125 288 moveto
+125 280 125 271 125 262 curveto
+stroke
+0.000 0.000 0.000 edgecolor
+newpath 128.5 262 moveto
+125 252 lineto
+121.5 262 lineto
+closepath fill
+1 setlinewidth
+solid
+0.000 0.000 0.000 edgecolor
+newpath 128.5 262 moveto
+125 252 lineto
+121.5 262 lineto
+closepath stroke
+grestore
+% Category
+gsave
+0.537 0.247 0.902 nodecolor
+newpath 171 36 moveto
+93 36 lineto
+93 0 lineto
+171 0 lineto
+closepath fill
+1 setlinewidth
+filled
+0.537 0.247 0.902 nodecolor
+newpath 171 36 moveto
+93 36 lineto
+93 0 lineto
+171 0 lineto
+closepath stroke
+0.000 0.000 0.000 nodecolor
+14 /Times-Roman set_font
+100.5 13.9 moveto 63 (Category) alignedtext
+grestore
+% BasicType()->Category
+gsave
+1 setlinewidth
+0.000 0.000 0.000 edgecolor
+newpath 57 144 moveto
+71 119 99 74 116 45 curveto
+stroke
+0.000 0.000 0.000 edgecolor
+newpath 119.2 46.44 moveto
+121 36 lineto
+113.08 43.04 lineto
+closepath fill
+1 setlinewidth
+solid
+0.000 0.000 0.000 edgecolor
+newpath 119.2 46.44 moveto
+121 36 lineto
+113.08 43.04 lineto
+closepath stroke
+grestore
+% CoercibleTo(a:Type)
+gsave
+0.537 0.247 0.902 nodecolor
+newpath 264 108 moveto
+116 108 lineto
+116 72 lineto
+264 72 lineto
+closepath fill
+1 setlinewidth
+filled
+0.537 0.247 0.902 nodecolor
+newpath 264 108 moveto
+116 108 lineto
+116 72 lineto
+264 72 lineto
+closepath stroke
+0.000 0.000 0.000 nodecolor
+14 /Times-Roman set_font
+123.5 85.9 moveto 133 (CoercibleTo\(a:Type\)) alignedtext
+grestore
+% CoercibleTo(OutputForm)->CoercibleTo(a:Type)
+gsave
+1 setlinewidth
+0.000 0.000 0.000 edgecolor
+newpath 200 144 moveto
+199 136 197 127 195 118 curveto
+stroke
+0.000 0.000 0.000 edgecolor
+newpath 198.39 117.12 moveto
+193 108 lineto
+191.53 118.49 lineto
+closepath fill
+1 setlinewidth
+solid
+0.000 0.000 0.000 edgecolor
+newpath 198.39 117.12 moveto
+193 108 lineto
+191.53 118.49 lineto
+closepath stroke
+grestore
+% SetCategory()->BasicType()
+gsave
+1 setlinewidth
+0.000 0.000 0.000 edgecolor
+newpath 105 216 moveto
+95 207 84 197 74 187 curveto
+stroke
+0.000 0.000 0.000 edgecolor
+newpath 75.83 183.95 moveto
+66 180 lineto
+71.22 189.22 lineto
+closepath fill
+1 setlinewidth
+solid
+0.000 0.000 0.000 edgecolor
+newpath 75.83 183.95 moveto
+66 180 lineto
+71.22 189.22 lineto
+closepath stroke
+grestore
+% SetCategory()->CoercibleTo(OutputForm)
+gsave
+1 setlinewidth
+0.000 0.000 0.000 edgecolor
+newpath 145 216 moveto
+155 207 166 197 176 187 curveto
+stroke
+0.000 0.000 0.000 edgecolor
+newpath 178.78 189.22 moveto
+184 180 lineto
+174.17 183.95 lineto
+closepath fill
+1 setlinewidth
+solid
+0.000 0.000 0.000 edgecolor
+newpath 178.78 189.22 moveto
+184 180 lineto
+174.17 183.95 lineto
+closepath stroke
+grestore
+% CoercibleTo(a:Type)->Category
+gsave
+1 setlinewidth
+0.000 0.000 0.000 edgecolor
+newpath 175 72 moveto
+168 63 160 53 152 44 curveto
+stroke
+0.000 0.000 0.000 edgecolor
+newpath 154.8 41.9 moveto
+146 36 lineto
+149.2 46.1 lineto
+closepath fill
+1 setlinewidth
+solid
+0.000 0.000 0.000 edgecolor
+newpath 154.8 41.9 moveto
+146 36 lineto
+149.2 46.1 lineto
+closepath stroke
+grestore
+% Package
+gsave
+0.333 1.000 0.933 nodecolor
+newpath 281 396 moveto
+209 396 lineto
+209 360 lineto
+281 360 lineto
+closepath fill
+1 setlinewidth
+filled
+0.333 1.000 0.933 nodecolor
+newpath 281 396 moveto
+209 396 lineto
+209 360 lineto
+281 360 lineto
+closepath stroke
+0.000 0.000 0.000 nodecolor
+14 /Times-Roman set_font
+217 373.9 moveto 56 (Package) alignedtext
+grestore
+endpage
+showpage
+grestore
+%%PageTrailer
+%%EndPage: 1
+%%Trailer
+end
+restore
+%%EOF
diff --git a/changelog b/changelog
index 048ebca..16787e3 100644
--- a/changelog
+++ b/changelog
@@ -1,3 +1,6 @@
+20100517 tpd src/axiom-website/patches.html 20100517.04.tpd.patch
+20100517 tpd books/bookvol10.2 fix the image to use .eps
+20100517 tpd books/ps/v102placescategory.eps use eps for bounding box
 20100517 tpd src/axiom-website/patches.html 20100517.03.tpd.patch
 20100517 tpd src/algebra/Makefile help and test for Divisor
 20100517 tpd books/bookvol5 expose Divisor
diff --git a/src/axiom-website/patches.html b/src/axiom-website/patches.html
index 2bf5c5c..ec7e453 100644
--- a/src/axiom-website/patches.html
+++ b/src/axiom-website/patches.html
@@ -2743,5 +2743,7 @@ books/bookvol10.2 add DivisorCategory<br/>
 books/bookvol10.2 add DIVCAT Description documentation<br/>
 <a href="patches/20100517.03.tpd.patch">20100517.03.tpd.patch</a>
 books/bookvol10.3 add Divisor<br/>
+<a href="patches/20100517.04.tpd.patch">20100517.04.tpd.patch</a>
+books/bookvol10.2 fix the image to use .eps<br/>
  </body>
 </html>
